import React, { useRef } from 'react'
import PropTypes from 'prop-types'
import { useMeasure } from 'react-use'
import Graph from './graph.jsx'
import Tooltip from './tooltip.jsx'
import Zoomable from './zoomable.jsx'
import Draggable from './draggable.jsx'
import Selectable from './selectable.jsx'
import Nodes from './nodes.jsx'
import Links from './links.jsx'
import DefaultTooltip from './default-tooltip.jsx'
import { renderIcon as renderIconDefault } from '../utils/images.js'


const FoundationGraph = ({
    definitions = [],
    results,
    links,
    renderIcon = renderIconDefault
}) => {
    const [ref, {width, height}] = useMeasure()
    const tooltipContainer = useRef(null)

    return (
        <div
            ref={ref}
            style={{
                position: 'relative',
                flex: '1 1 auto',
                height: '100%'
            }}
        >
            <Graph
                width={width}
                height={height}
                nodes={results.map(obj => ({ ...obj }))}
                links={links.map(obj => ({ ...obj }))}
            >
                <Tooltip
                    container={tooltipContainer}
                    component={props => (
                        <DefaultTooltip
                            {...props}
                            definitions={definitions}
                        />
                    )}
                >
                    {({ setTooltip }) => (
                        <>
                            <Links />
                            <Nodes
                                image={(...args) => renderIcon(definitions, ...args)}
                                onMouseMove={(node, position) => {
                                    setTooltip(node && { node, position })
                                }}
                            />
                        </>
                    )}
                </Tooltip>
                <Zoomable />
                <Draggable />
                <Selectable />
            </Graph>
            <aside ref={tooltipContainer} />
        </div>
    )
}

FoundationGraph.propTypes = {
    definitions: PropTypes.array,
    results: PropTypes.array,
    links: PropTypes.array
}

export default FoundationGraph