import { createContext } from 'react'

/**
 * Exposes top-level graph data, simulation, and more.
 * 
 * @type {object}
 */
export const GraphContext = createContext({
    simulation: null,
    nodes: null,
    links: null
})

/**
 * Account for canvas offset in the given x and y coordinates.
 *
 * @param  {number} x 	   - X coordinate
 * @param  {number} y 	   - Y coordinate
 * @param  {object} canvas - A canvas element
 * @return {object} 	   - The offset `x` and `y` coordinates
 */
export const getRelativePosition = (x, y, canvas) => {
    const {top, left} = canvas.getBoundingClientRect()

    return {
        x: x - left,
        y: y - top
    }
}